Class UpdateApplicationLayerAutomaticResponseRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.shield.model.ShieldRequest
software.amazon.awssdk.services.shield.model.UpdateApplicationLayerAutomaticResponseRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateApplicationLayerAutomaticResponseRequest.Builder,UpdateApplicationLayerAutomaticResponseRequest>
@Generated("software.amazon.awssdk:codegen")
public final class UpdateApplicationLayerAutomaticResponseRequest
extends ShieldRequest
implements ToCopyableBuilder<UpdateApplicationLayerAutomaticResponseRequest.Builder,UpdateApplicationLayerAutomaticResponseRequest>
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionfinal ResponseActionaction()Specifies the action setting that Shield Advanced should use in the WAF rules that it creates on behalf of the protected resource in response to DDoS attacks.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe ARN (Amazon Resource Name) of the resource.static Class<? extends UpdateApplicationLayerAutomaticResponseRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
resourceArn
The ARN (Amazon Resource Name) of the resource.
- Returns:
- The ARN (Amazon Resource Name) of the resource.
-
action
Specifies the action setting that Shield Advanced should use in the WAF rules that it creates on behalf of the protected resource in response to DDoS attacks. You specify this as part of the configuration for the automatic application layer DDoS mitigation feature, when you enable or update automatic mitigation. Shield Advanced creates the WAF rules in a Shield Advanced-managed rule group, inside the web ACL that you have associated with the resource.
- Returns:
- Specifies the action setting that Shield Advanced should use in the WAF rules that it creates on behalf of the protected resource in response to DDoS attacks. You specify this as part of the configuration for the automatic application layer DDoS mitigation feature, when you enable or update automatic mitigation. Shield Advanced creates the WAF rules in a Shield Advanced-managed rule group, inside the web ACL that you have associated with the resource.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateApplicationLayerAutomaticResponseRequest.Builder,UpdateApplicationLayerAutomaticResponseRequest> - Specified by:
toBuilderin classShieldRequest
-
builder
-
serializableBuilderClass
public static Class<? extends UpdateApplicationLayerAutomaticResponseRequest.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-